@@ -54,10 +54,6 @@ struct _EvApplication {
 
 	EggToolbarsModel *toolbars_model;
 
-#ifndef HAVE_GTK_RECENT
-	EggRecentModel  *recent_model;
-#endif
-
 	TotemScrsaver *scr_saver;
 
 	gchar *last_chooser_uri;
@@ -326,6 +322,18 @@ get_destination_from_args (GHashTable *args)
 	return dest;
 }
 
+static const gchar *
+get_find_string_from_args (GHashTable *args)
+{
+	GValue *value = NULL;
+
+	g_assert (args != NULL);
+
+	value = g_hash_table_lookup (args, "find-string");
+	
+	return value ? g_value_get_string (value) : NULL;
+}
+
 /**
  * get_unlink_temp_file_from_args:
  * @args: a #GHashTable with data passed to the application.
@@ -524,6 +532,7 @@ ev_application_open_uri_at_dest (EvApplication  *application,
 				 GdkScreen      *screen,
 				 EvLinkDest     *dest,
 				 EvWindowRunMode mode,
+				 const gchar    *search_string,
 				 gboolean        unlink_temp_file,
 				 const gchar    *print_settings, 
 				 guint           timestamp)
@@ -549,7 +558,7 @@ ev_application_open_uri_at_dest (EvApplication  *application,
 
 	/* We need to load uri before showing the window, so
 	   we can restore window size without flickering */	
-	ev_window_open_uri (new_window, uri, dest, mode,
+	ev_window_open_uri (new_window, uri, dest, mode, search_string, 
 			    unlink_temp_file, print_settings);
 
 	ev_document_fc_mutex_lock ();
@@ -577,21 +586,24 @@ ev_application_open_uri (EvApplication  *application,
 {
 	EvLinkDest      *dest = NULL;
 	EvWindowRunMode  mode = EV_WINDOW_MODE_NORMAL;
+	const gchar     *search_string = NULL;
 	gboolean         unlink_temp_file = FALSE;
-	const gchar     *print_settings;
+	const gchar     *print_settings = NULL;
 	GdkScreen       *screen = NULL;
 
 	if (args) {
 		screen = get_screen_from_args (args);
 		dest = get_destination_from_args (args);
 		mode = get_window_run_mode_from_args (args);
+		search_string = get_find_string_from_args (args);
 		unlink_temp_file = (mode == EV_WINDOW_MODE_PREVIEW &&
 				    get_unlink_temp_file_from_args (args));
 		print_settings = get_print_settings_from_args (args);
 	}
 	
 	ev_application_open_uri_at_dest (application, uri, screen,
-					 dest, mode, unlink_temp_file,
+					 dest, mode, search_string,
+					 unlink_temp_file,
 					 print_settings, timestamp);
 
 	if (dest)
@@ -610,8 +622,8 @@ ev_application_open_uri_list (EvApplication *application,
 
 	for (l = uri_list; l != NULL; l = l->next) {
 		ev_application_open_uri_at_dest (application, (char *)l->data,
-						 screen, NULL, 0, FALSE,
-						 NULL, timestamp);
+						 screen, NULL, 0, NULL,
+						 FALSE, NULL, timestamp);
 	}
 }
 
@@ -625,13 +637,6 @@ ev_application_shutdown (EvApplication *application)
 		application->toolbars_file = NULL;
 	}
 
-#ifndef HAVE_GTK_RECENT
-	if (application->recent_model) {
-		g_object_unref (application->recent_model);
-		application->recent_model = NULL;
-	}
-#endif
-
 #ifdef WITH_GTK_PRINT
 #if GTK_CHECK_VERSION (2, 11, 0)
 	if (application->print_settings_file) {
@@ -675,6 +680,8 @@ ev_application_class_init (EvApplicationClass *ev_application_class)
 static void
 ev_application_init (EvApplication *ev_application)
 {
+	gint i;
+	
 #if WITH_GNOME
 	init_session (ev_application);
 #endif
@@ -693,18 +700,24 @@ ev_application_init (EvApplication *ev_application)
 						  DATADIR"/evince-toolbar.xml");
 	}
 
-	egg_toolbars_model_set_flags (ev_application->toolbars_model, 0,
-				      EGG_TB_MODEL_NOT_REMOVABLE); 
+	/* Open item doesn't exist anymore,
+	 * convert it to OpenRecent for compatibility
+	 */
+	for (i = 0; i < egg_toolbars_model_n_items (ev_application->toolbars_model, 0); i++) {
+		const gchar *item;
+		
+		item = egg_toolbars_model_item_nth (ev_application->toolbars_model, 0, i);
+		if (g_ascii_strcasecmp (item, "FileOpen") == 0) {
+			egg_toolbars_model_remove_item (ev_application->toolbars_model, 0, i);
+			egg_toolbars_model_add_item (ev_application->toolbars_model, 0, i,
+						     "FileOpenRecent");
+			ev_application_save_toolbars_model (ev_application);
+			break;
+		}
+	}
 
-#ifndef HAVE_GTK_RECENT
-	ev_application->recent_model = egg_recent_model_new (EGG_RECENT_MODEL_SORT_MRU);
-	/* FIXME we should add a mime type filter but current eggrecent
-           has only a varargs style api which does not work well when
-	   the list of mime types is dynamic */
-	egg_recent_model_set_limit (ev_application->recent_model, 5);	
-	egg_recent_model_set_filter_groups (ev_application->recent_model,
-    	    	    			    "Evince", NULL);
-#endif /* HAVE_GTK_RECENT */
+	egg_toolbars_model_set_flags (ev_application->toolbars_model, 0,
+				      EGG_TB_MODEL_NOT_REMOVABLE);
 }
 
 /**
@@ -740,14 +753,6 @@ ev_application_get_toolbars_model (EvApplication *application)
 	return application->toolbars_model;
 }
 
-#ifndef HAVE_GTK_RECENT
-EggRecentModel *
-ev_application_get_recent_model (EvApplication *application)
-{
-	return application->recent_model;
-}
-#endif
-
 void
 ev_application_save_toolbars_model (EvApplication *application)
 {
